@@ -1,3 +1,4 @@
+use 5.008;
 use strict;
 use warnings;
 package BenchmarkAnything::Storage::Frontend::Lib;
@@ -5,7 +6,7 @@ BEGIN {
   $BenchmarkAnything::Storage::Frontend::Lib::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: Basic functions to access a BenchmarkAnything store
-$BenchmarkAnything::Storage::Frontend::Lib::VERSION = '0.009';
+$BenchmarkAnything::Storage::Frontend::Lib::VERSION = '0.010';
 use Scalar::Util 'reftype';
 
 
@@ -13,7 +14,8 @@ sub new
 {
         my $class = shift;
         my $self  = bless { @_ }, $class;
-        $self->_read_config unless $self->{noconfig};
+        require BenchmarkAnything::Config;
+        $self->{config} = BenchmarkAnything::Config->new(cfgfile => $self->{cfgfile}) unless $self->{noconfig};
         $self->connect      unless $self->{noconnect};
         return $self;
 }
@@ -175,34 +177,6 @@ sub _output_format
 }
 
 
-sub _read_config
-{
-        my ($self) = @_;
-
-        require File::HomeDir;
-        require File::Slurp;
-        require YAML::Any;
-
-        # don't look into user's homedir if we are running tests
-        my $default_cfgfile = $ENV{HARNESS_ACTIVE} ? "t/benchmarkanything.cfg" : File::HomeDir->my_home . "/.benchmarkanything/default.cfg";
-
-        # read file
-        eval {
-                $self->{cfgfile} = $self->{cfgfile} || $ENV{BENCHMARKANYTHING_CONFIGFILE} || $default_cfgfile;
-                $self->{config}  = YAML::Any::Load("".File::Slurp::read_file($self->{cfgfile}));
-        };
-        if ($@)
-        {
-                die "benchmarkanything: error loading configfile: $@\n";
-        }
-
-        # defaults
-        $self->{config}{benchmarkanything}{backend} ||= 'local';
-
-        return $self;
-}
-
-
 sub connect
 {
         my ($self) = @_;
@@ -466,13 +440,11 @@ sub add
         }
         elsif ($backend eq 'http')
         {
-                my $ua  = $self->_get_user_agent;
-                my $url = $self->_get_base_url."/api/v1/add";
-                print "Add data [backend:http]...\n" if $self->{verbose} or $self->{debug};
-                my $res = $ua->post($url => json => $data)->res;
-                print "Done.\n" if $self->{verbose} or $self->{debug};
-
-                die "benchmarkanything: ".$res->error->{message}." ($url)\n" if $res->error;
+                require BenchmarkAnything::Reporter;
+                $self->{config} = BenchmarkAnything::Reporter->new(config  => $self->{config},
+                                                                   verbose => $self->{verbose},
+                                                                   debug   => $self->{debug},
+                                                                  );
         }
         else
         {
@@ -484,13 +456,8 @@ sub add
 
 sub _get_user_agent
 {
-        my ($self) = @_;
-
         require Mojo::UserAgent;
-
-        # query
-        my $ua    = Mojo::UserAgent->new;
-        return $ua;
+        return Mojo::UserAgent->new;
 }
 
 sub _get_base_url
@@ -634,6 +601,14 @@ Instantiate a new object.
 Path to config file. If not provided it uses env variable
 C<BENCHMARKANYTHING_CONFIGFILE> or C<$home/.benchmarkanything.cfg>.
 
+=item * noconfig
+
+If set to 1, do not initialize configuration.
+
+=item * noconnect
+
+If set to 1, do not automatically connect to backend store.
+
 =item * really
 
 Used for critical functions like createdb. Provide a true value or, in
@@ -762,15 +737,6 @@ Such additional markup lets outer arrays look like this:
  3:[Affe=amazing moves in the jungle;Zomtec=slow talking speed;Birne=unexpected in many respects]
  4:[single report string]
 
-=head2 _read_config
-
-Internal function.
-
-Reads the config file; either from given file name, or env variable
-C<BENCHMARKANYTHING_CONFIGFILE> or C<$home/.benchmarkanything.cfg>.
-
-Returns the object to allow chained method calls.
-
 =head2 connect
 
 Connects to the database according to the DB handle from config.
